@@ -3,7 +3,6 @@ Definition of the base objects for the creation of a spec validator
 """
 import logging
 import os
-import pathlib
 from io import BytesIO
 from numbers import Integral
 from numbers import Real
@@ -99,7 +98,16 @@ class FITSFloatValidator:
 class SpecSchema:
     """
     Define a schema that is used to validate FITS headers for a spec based upon structured definitions
-    in YAML or dicts
+    in YAML or dicts.
+
+    Parameters
+    ----------
+    spec_schema_definitions
+        Definition of the spec's schema in one of the following forms:
+            - Dict definition of the spec schema
+            - List of Dict definitions of the spec schema
+            - Path to a YAML file defining the spec schema
+            - Path to a directory containing YAML files defining spec schema
     """
 
     # Schemas defined for a spec have the following structure per key
@@ -116,15 +124,6 @@ class SpecSchema:
     definition_schema = vol.Schema(definition_schema_definition, extra=vol.ALLOW_EXTRA)
 
     def __init__(self, spec_schema_definitions: Union[Path, dict, List[dict]]):
-        """
-        Constructor for the SpecSchema which builds a voluptuous schema from
-        specification definition files in YAML or dicts
-        :param spec_schema_definitions: Definition of the spec's schema in one of the following forms
-            - Dict definition of the spec schema
-            - List of Dict definitions of the spec schema
-            - Path to a YAML file defining the spec schema
-            - Path to a directory containing YAML files defining spec schema
-        """
         # convert spec schema definitions to a list of dicts
         self.spec_schema_definitions = self._parse_spec_schema_definitions(spec_schema_definitions)
         # validate the dict definition of the spec schema
@@ -178,8 +177,15 @@ class SpecSchema:
     def expand_schema(self, headers) -> dict:
         """
         Expand schema indices using information from fits headers
-        :param headers: Fits file headers whose values are to be used to know how to expand spec keys
-        :return: schema dictionary
+
+        Parameters
+        ----------
+        headers
+            Fits file headers whose values are to be used to know how to expand spec keys
+
+        Returns
+        -------
+        schema dictionary
         """
         # 214 Expansion
         if {"DAAXES", "DEAXES", "DNAXIS"}.issubset(headers.keys()):
@@ -193,8 +199,14 @@ class SpecSchema:
     def generate_schema_for_key(key_schema):
         """
         Generate voluptuous schema for a key
-        :param key_schema: Spec schema (from yml) used to generate voluptuous schema
-        :return: Voluptuous schema for a key
+
+        Parameters
+        ----------
+        key_schema
+            Spec schema (from yml) used to generate voluptuous schema
+        Returns
+        -------
+        Voluptuous schema for a key
         """
         type_map = {"int": Integral, "float": Real, "str": str, "bool": bool}
 
@@ -276,12 +288,18 @@ class SpecSchema:
         """
         Validate headers against the instance spec schema
         raising voluptuous errors on failure
-        :param headers: header dict to validate
-        :return: vol.Schema
+
+        Parameters
+        ----------
+        headers
+            header dict to validate
+        extra
+
+        Returns
+        -------
+        vol.Schema
+
         """
-        """for value in self.spec_schema_definitions.values():
-            if value["values_range"]:
-                pass"""
 
         spec_schema = self._create_spec_schema(headers, extra)
         return spec_schema(headers)
@@ -290,6 +308,21 @@ class SpecSchema:
 class SpecValidator:
     """
     Validates FITS Headers against a schema
+
+    Parameters
+    ----------
+    spec_schema
+        Definition of the spec's schema in one of the following forms:
+            - SpecSchema instance
+            - Dict definition of the spec schema
+            - List of Dict definitions of the spec schema
+            - Path to a YAML file defining the spec schema
+            - Path to a directory containing YAML files defining spec schema
+
+    SchemaValidationException
+        SpecValidationException or subclass of SpecValidationException
+            to raise if spec_validator validation fails
+
     """
 
     def __init__(
@@ -297,17 +330,6 @@ class SpecValidator:
         spec_schema: Union[Path, PurePath, dict, List[dict], SpecSchema],
         SchemaValidationException: Type[SpecValidationException] = SpecValidationException,
     ):
-        """
-        Constructor for the SpecValidator
-        :param spec_schema: Definition of the spec's schema in one of the following forms
-            - SpecSchema instance
-            - Dict definition of the spec schema
-            - List of Dict definitions of the spec schema
-            - Path to a YAML file defining the spec schema
-            - Path to a directory containing YAML files defining spec schema
-        :param SchemaValidationException: SpecValidationException or subclass of SpecValidationException
-            to raise if spec_validator validation fails
-        """
         # Callable for validating a dict against the defined spec_validator
         if isinstance(spec_schema, SpecSchema):
             self.spec_schema = spec_schema
@@ -336,10 +358,21 @@ class SpecValidator:
     def verify_headers(self, headers, extra) -> dict:
         """
         Validates file headers against the instance spec_validator
-        :param headers: file headers
-        :param extra: switch for validation to allow extra keys in schema
-        :return: dict of headers
-        :raises: SchemaValidationException
+
+        Parameters
+        ----------
+        headers
+            file headers
+        extra
+            switch for validation to allow extra keys in schema
+        Returns
+        -------
+        dict of headers
+
+        Raises
+        ------
+        SchemaValidationException
+
         """
 
         validation_errors = {}
@@ -590,23 +623,36 @@ class SpecValidator:
     def validate(self, input_headers, return_type=HDUList, extra=True):
         """
         Validates against the instance spec_schema
-        :param input_headers: The headers to validate in the following formats:
-            - string file path
-            - File like object
-            - HDUList object
-            - fits.header.Header object
-            - Dictionary of header keys and values
-        :param return_type: determines return type. Default is HDUList. May be one of:
-            - dict
-            - BytesIO
-            - fits.header.Header
-            - Path (file)
-            - HDUList
-            - fits.PrimaryHDU
-        :param extra: switch for validation to allow extra keys in schema. Default is true, which will
-        allow extra keys. Ingest validation should allow extra keys.
-        :return: formatted headers
-        :raises: SpecValidationException or subclass
+
+        Parameters
+        ----------
+        input_headers
+            The headers to validate in the following formats:
+                - string file path
+                - File like object
+                - HDUList object
+                - fits.header.Header object
+                - Dictionary of header keys and values
+
+        return_type
+            Determines return type. Default is HDUList. May be one of:
+                - dict
+                - BytesIO
+                - fits.header.Header
+                - Path (file)
+                - HDUList
+                - fits.PrimaryHDU
+        extra
+            Switch for validation to allow extra keys in schema. Default is true, which will
+            allow extra keys. Ingest validation should allow extra keys.
+
+        Returns
+        -------
+        Formatted headers
+
+        Raises
+        ------
+        dkist_header_validator.SpecValidationException or subclass
         """
         if isinstance(input_headers, (dict, fits.header.Header, HDUList)):
             validated_headers, fits_cards = self._validate_headers(input_headers, extra)
@@ -619,23 +665,36 @@ class SpecValidator:
     def validate_and_translate_to_214_l0(self, input_headers, return_type=HDUList, extra=True):
         """
         Validates against the instance spec_schema and then translates to the spec214_l0 schema
-        :param input_headers: The headers to validate in the following formats:
-            - string file path
-            - File like object
-            - HDUList object
-            - fits.header.Header object
-            - Dictionary of header keys and values
-        :param return_type: determines return type. Default is HDUList. May be one of:
-            - dict
-            - BytesIO
-            - fits.header.Header
-            - Path (file)
-            - HDUList
-            - fits.PrimaryHDU
-        :param extra: switch for validation to allow extra keys in schema. Default is true, which will
-        allow extra keys. Ingest validation should allow extra keys.
-        :return: formatted 214 l0 headers
-        :raises: SpecValidationException or subclass
+
+        Parameters
+        ----------
+        input_headers
+            The headers to validate in the following formats:
+                - string file path
+                - File like object
+                - HDUList object
+                - fits.header.Header object
+                - Dictionary of header keys and values
+
+        return_type
+            Determines return type. Default is HDUList. May be one of:
+                - dict
+                - BytesIO
+                - fits.header.Header
+                - Path (file)
+                - HDUList
+                - fits.PrimaryHDU
+        extra
+            Switch for validation to allow extra keys in schema. Default is true, which will
+            allow extra keys. Ingest validation should allow extra keys.
+
+        Returns
+        -------
+        Formatted 214 l0 headers
+
+        Raises
+        ------
+        dkist_header_validator.SpecValidationException or subclass
         """
         if isinstance(input_headers, (dict, fits.header.Header, HDUList)):
             validated_headers, fits_cards = self._validate_headers(input_headers, extra)
